<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" omit-xml-declaration="no" indent="no" media-type="text/html"/>
	<!--XSL Stylesheet for generating Datasheet-->
	<xsl:template match="datasheet">
		<html>
			<head>
				<title>
					<xsl:value-of select="manufacturer"/>
					<xsl:value-of select="productline"/>
					Product Line - Data Sheet
				</title>
			</head>
			<body>
				<p align="right">
					<img src="Altova_right_300.gif" alt="Altova logo"/>
				</p>
				<h1>
					<xsl:value-of select="manufacturer"/>
					<xsl:value-of select="productline"/>
					Product Line - Data Sheet
				</h1>
				<!--
				<h2>Document Information</h2>
				<table border="1" cellpadding="4">
					<tr>
						<td>ID</td>
						<td>
							<input>
								<xsl:attribute name="value"><xsl:value-of select="documentid"/></xsl:attribute>
							</input>
						</td>
					</tr>
					<tr>
						<td>Company</td>
						<td>
							<input>
								<xsl:attribute name="value"><xsl:value-of select="manufacturer"/></xsl:attribute>
							</input>
						</td>
					</tr>
					<tr>
						<td>Line</td>
						<td>
							<input>
								<xsl:attribute name="value"><xsl:value-of select="productline"/></xsl:attribute>
							</input>
						</td>
					</tr>
					<tr>
						<td>Security</td>
						<td>
							<table>
								<tr>
									<td>Classification</td>
									<td>
										<input>
											<xsl:attribute name="value"><xsl:value-of select="security/classification"/></xsl:attribute>
										</input>
									</td>
								</tr>
								<tr>
									<td>Level</td>
									<td>
										<input>
											<xsl:attribute name="value"><xsl:value-of select="security/level"/></xsl:attribute>
										</input>
									</td>
								</tr>
								<tr>
									<td>Effective</td>
									<td>
										<input>
											<xsl:attribute name="value"><xsl:value-of select="security/effective"/></xsl:attribute>
										</input>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>Tracking</td>
						<td>
							<xsl:for-each select="tracking">
								<table>
									<tr>
										<td>Operation</td>
										<td>Date</td>
										<td>Time</td>
										<td>By</td>
										<td>Dpt.</td>
										<td>Status</td>
										<td>Changes</td>
									</tr>
									<xsl:for-each select="modification">
										<xsl:apply-templates select="."/>
									</xsl:for-each>
								</table>
							</xsl:for-each>
						</td>
					</tr>
				</table>
				<h2>Document Contents</h2>
				-->
				<table width="100%">
					<tr valign="top">
						<td>
							<xsl:for-each select="description">
								<xsl:apply-templates select="."/>
							</xsl:for-each>
						</td>
						<td>
							<table width="100%" cellspacing="10">
								<xsl:for-each select="diagrams">
									<tr>
										<xsl:apply-templates select="."/>
									</tr>
								</xsl:for-each>
								<tr>
									<td colspan="2">
										<xsl:apply-templates select="models"/>
									</td>
								</tr>
								<xsl:for-each select="copyright">
									<tr>
										<td colspan="2" align="right">
											<br/>
											<br/>
											<xsl:for-each select="para">
												<small>
													<xsl:apply-templates/>
													<br/>
												</small>
											</xsl:for-each>
										</td>
									</tr>
								</xsl:for-each>
							</table>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="modification">
		<tr>
			<td>
				<input size="8">
					<xsl:attribute name="value"><xsl:value-of select="@operation"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="8">
					<xsl:attribute name="value"><xsl:value-of select="date"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="8">
					<xsl:attribute name="value"><xsl:value-of select="time"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="10">
					<xsl:attribute name="value"><xsl:value-of select="by"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="10">
					<xsl:attribute name="value"><xsl:value-of select="department"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="8">
					<xsl:attribute name="value"><xsl:value-of select="status"/></xsl:attribute>
				</input>
			</td>
			<td>
				<input size="30">
					<xsl:attribute name="value"><xsl:value-of select="changes"/></xsl:attribute>
				</input>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="models">
		<table width="100%">
			<tr>
				<td>Principal Characteristics</td>
				<xsl:for-each select="model">
					<td bgcolor="808080">
						<b>
							<xsl:value-of select="Name"/>
						</b>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Max. Takeoff Weight</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="MaxTakeoffWeight"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Max. Landing Weight</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="MaxLandingWeight"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Engines</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="EngineOfferings"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Fuel Capacity</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="FuelCapacity"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Cruise Mach</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="CruiseMach"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Passengers</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="Passengers"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>DesignRange</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="DesignRange"/>
					</td>
				</xsl:for-each>
			</tr>
			<tr bgcolor="C0C0C0">
				<td>Pallets</td>
				<xsl:for-each select="model">
					<td>
						<xsl:value-of select="Pallets"/>
					</td>
				</xsl:for-each>
			</tr>
		</table>
	</xsl:template>
	<xsl:template match="diagram">
		<td>
			<h3>
				<xsl:value-of select="title"/>
			</h3>
			<img alt="Diagram">
				<xsl:attribute name="src"><xsl:value-of select="source"/></xsl:attribute>
			</img>
			<xsl:for-each select="description">
				<xsl:for-each select="para">
					<p>
						<small>
							<xsl:apply-templates/>
						</small>
					</p>
				</xsl:for-each>
			</xsl:for-each>
		</td>
	</xsl:template>
	<xsl:template match="description">
		<xsl:for-each select="para">
			<p>
				<xsl:apply-templates/>
			</p>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="bold">
		<b>
			<xsl:apply-templates/>
		</b>
	</xsl:template>
	<xsl:template match="italic">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>
</xsl:stylesheet>
